@@ -4,7 +4,6 @@ from typing import Any
 
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.arm.base_resource_check import BaseResourceCheck
-from checkov.common.parsers.node import DictNode
 
 
 class AKSRbacEnabled(BaseResourceCheck):
@@ -23,7 +22,7 @@ class AKSRbacEnabled(BaseResourceCheck):
                 return CheckResult.FAILED
 
         properties = conf.get('properties')
-        if not properties or not isinstance(properties, DictNode):
+        if not properties or not isinstance(properties, dict):
             return CheckResult.FAILED
         enable_RBAC = properties.get('enableRBAC')
         if str(enable_RBAC).lower() == "true":
