@@ -27,6 +27,9 @@ class AbsSecurityGroupUnrestrictedIngress(BaseResourceCheck):
                 rules = []
                 rules.append(conf['Properties'])
 
+        if not isinstance(rules, list):
+            return CheckResult.UNKNOWN
+
         for rule in rules:
             if rule.__contains__('FromPort') and rule.__contains__('ToPort'):
                 if isinstance(rule['FromPort'], int) and isinstance(rule['ToPort'], int):
@@ -35,4 +38,4 @@ class AbsSecurityGroupUnrestrictedIngress(BaseResourceCheck):
                             return CheckResult.FAILED
                         elif 'CidrIpv6' in rule.keys() and rule['CidrIpv6'] in ['::/0', '0000:0000:0000:0000:0000:0000:0000:0000/0']:
                             return CheckResult.FAILED
-        return CheckResult.PASSED
\ No newline at end of file
+        return CheckResult.PASSED
