@@ -484,4 +484,8 @@ class CloudformationVariableRenderer(VariableRenderer):
                 val_to_eval[cfn_evaluation_function], dest_vertex_attributes)
             changed_origin_id = edge.dest
 
-        return evaluated_value, changed_origin_id, attribute_at_dest
\ No newline at end of file
+        return evaluated_value, changed_origin_id, attribute_at_dest
+
+    def evaluate_non_rendered_values(self) -> None:
+        # not used
+        pass
