@@ -24,7 +24,7 @@ CFN_RESOURCE_TYPE_IDENTIFIER = re.compile(r"^[a-zA-Z0-9]+::[a-zA-Z0-9]+::[a-zA-Z
 
 class CustomPoliciesIntegration(BaseIntegrationFeature):
     def __init__(self, bc_integration: BcPlatformIntegration) -> None:
-        super().__init__(bc_integration=bc_integration, order=1)  # must be after policy metadata
+        super().__init__(bc_integration=bc_integration, order=1)  # must be after policy metadata and before suppression integration
         self.platform_policy_parser = NXGraphCheckParser()
         self.policies_url = f"{self.bc_integration.api_url}/api/v1/policies/table/data"
         self.bc_cloned_checks: dict[str, list[dict[str, Any]]] = defaultdict(list)
@@ -100,6 +100,10 @@ class CustomPoliciesIntegration(BaseIntegrationFeature):
         bc_check_ids = [record.bc_check_id for record in records]
         for idx, bc_check_id in enumerate(bc_check_ids):
             cloned_policies = self.bc_cloned_checks.get(bc_check_id, [])  # type:ignore[arg-type]  # bc_check_id can be None
+            logging.debug('Cloned policies to be deep copied:')
+            logging.debug(cloned_policies)
+            logging.debug('From origin policy:')
+            logging.debug(records[idx].get_unique_string())
             for cloned_policy in cloned_policies:
                 new_record = deepcopy(records[idx])
                 new_record.check_id = cloned_policy['id']
@@ -110,5 +114,9 @@ class CustomPoliciesIntegration(BaseIntegrationFeature):
                 records.append(new_record)
         return records
 
+    def pre_runner(self) -> None:
+        # not used
+        pass
+
 
 integration = CustomPoliciesIntegration(bc_integration)
