@@ -71,6 +71,8 @@ _registry_instances: dict[str, Registry] = {}
 
 def get_graph_checks_registry(check_type: str) -> Registry:
     if not _registry_instances.get(check_type):
-        _registry_instances[check_type] = Registry(parser=NXGraphCheckParser(),
-                             checks_dir=f"{Path(__file__).parent.parent.parent}/{check_type}/checks/graph_checks")
+        _registry_instances[check_type] = Registry(
+            parser=NXGraphCheckParser(),
+            checks_dir=f"{Path(__file__).parent.parent.parent}/{check_type}/checks/graph_checks",
+        )
     return _registry_instances[check_type]
