@@ -7,5 +7,5 @@ from .contains_attribute_solver import ContainsAttributeSolver
 class NotContainsAttributeSolver(ContainsAttributeSolver):
     operator = Operators.NOT_CONTAINS  # noqa: CCE003  # a static attribute
 
-    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:  # type:ignore[override]
+    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:
         return not super()._get_operation(vertex, attribute)
