@@ -11,6 +11,6 @@ class GraphRecord(Record):
                          record.file_line_range, record.resource, record.evaluations, record.check_class,
                          record.file_abs_path, record.entity_tags, record.caller_file_path,
                          record.caller_file_line_range, bc_check_id=record.bc_check_id, resource_address=record.resource_address,
-                         severity=record.severity, bc_category=record.bc_category, benchmarks=record.benchmarks)
+                         severity=record.severity, bc_category=record.bc_category, benchmarks=record.benchmarks, details=record.details)
         self.fixed_definition = record.fixed_definition
         self.breadcrumbs = breadcrumbs
