@@ -1,3 +1,4 @@
+import tarfile
 import base64
 import gzip
 import io
@@ -8,6 +9,11 @@ def convert_to_unix_path(path: str) -> str:
     return path.replace('\\', '/')
 
 
+def extract_tar_archive(source_path: str, dest_path: str) -> None:
+    with tarfile.open(source_path) as tar:
+        tar.extractall(path=dest_path)
+
+
 def compress_file_gzip_base64(input_path: str) -> str:
     try:
         with open(input_path, 'rb') as json_results_file:
