@@ -1,3 +1,7 @@
+from __future__ import annotations
+
+from typing import Any
+
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.github.base_github_configuration_check import BaseGithubCheck
 from checkov.github.schemas.repository_collaborators import schema as repository_collaborators_schema
@@ -5,7 +9,7 @@ from checkov.json_doc.enums import BlockType
 
 
 class RepositoryCollaborators(BaseGithubCheck):
-    def __init__(self):
+    def __init__(self) -> None:
         name = "Ensure 2 admins are set for each repository"
         id = "CKV_GITHUB_9"
         categories = [CheckCategories.SUPPLY_CHAIN]
@@ -17,7 +21,7 @@ class RepositoryCollaborators(BaseGithubCheck):
             block_type=BlockType.DOCUMENT
         )
 
-    def scan_entity_conf(self, conf):
+    def scan_entity_conf(self, conf: dict[str, Any], entity_type: str) -> tuple[CheckResult, dict[str, Any]] | None:  # type:ignore[override]
         admin_collaborators = 0
         if repository_collaborators_schema.validate(conf):
             for item in conf:
@@ -31,6 +35,7 @@ class RepositoryCollaborators(BaseGithubCheck):
 
             else:
                 return CheckResult.FAILED, conf
+        return None
 
 
 check = RepositoryCollaborators()
