@@ -48,8 +48,7 @@ class Runner(ImageReferencerMixin["dict[str, dict[str, Any] | list[dict[str, Any
         return (".gitlab-ci.yml", ".gitlab-ci.yaml")
 
     def get_resource(self, file_path: str, key: str, supported_entities: Iterable[str],
-                     definitions: dict[str, Any] | None = None) -> str:
-        start_line, end_line = self.get_start_and_end_lines(key)
+                     start_line: int = -1, end_line: int = -1) -> str:
         file_config = force_dict(self.definitions[file_path])
         if not file_config:
             return key
@@ -102,4 +101,4 @@ class Runner(ImageReferencerMixin["dict[str, dict[str, Any] | list[dict[str, Any
             manager = GitlabCiImageReferencerManager(workflow_config=config, file_path=file)
             images.extend(manager.extract_images_from_workflow())
 
-        return images
\ No newline at end of file
+        return images
