@@ -13,9 +13,10 @@ class ApiServerRequestTimeout(BaseK8sContainerCheck):
 
     def scan_container_conf(self, metadata: Dict[str, Any], conf: Dict[str, Any]) -> CheckResult:
         self.evaluated_container_keys = ["command"]
-        if "command" in conf:
-            if "kube-apiserver" in conf["command"]:
-                for cmd in conf["command"]:
+        command = conf.get("command")
+        if isinstance(command, list):
+            if "kube-apiserver" in command:
+                for cmd in command:
                     if cmd == "--request-timeout":
                         return CheckResult.FAILED
                     if "=" in cmd:
