@@ -18,7 +18,8 @@ from checkov.common.util.type_forcers import force_list
 from checkov.kubernetes.parser.parser import parse
 
 K8_POSSIBLE_ENDINGS = {".yaml", ".yml", ".json"}
-DEFAULT_NESTED_RESOURCE_TYPE = 'Pod'
+DEFAULT_NESTED_RESOURCE_TYPE = "Pod"
+FILTERED_RESOURCES_FOR_EDGE_BUILDERS = ["NetworkPolicy"]
 
 
 def get_folder_definitions(
@@ -218,6 +219,12 @@ def get_resource_id(resource: dict[str, Any] | None) -> str | None:
     return None
 
 
+def remove_metadata_from_attribute(attribute: dict[str, Any] | None) -> None:
+    if isinstance(attribute, dict):
+        attribute.pop("__startline__", None)
+        attribute.pop("__endline__", None)
+
+
 @dataclass()
 class K8sGraphFlags:
     create_complex_vertices: bool
