@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Any
+from typing import Any, Union, List
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.common.checks.enums import BlockType
 from checkov.openapi.checks.resource.v2.BaseOpenapiCheckV2 import BaseOpenapiCheckV2
@@ -16,9 +16,11 @@ class Oauth2SecurityRequirement(BaseOpenapiCheckV2):
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_resources,
                          block_type=BlockType.DOCUMENT)
 
-    def scan_openapi_conf(self, conf: dict[str, Any], entity_type: str) -> tuple[CheckResult, dict[str, Any]]:
-        security_values = conf.get("security", [{}])
-        security_definitions = conf.get("securityDefinitions", {})
+    def scan_openapi_conf(  # type:ignore[override]
+        self, conf: dict[str, Any], entity_type: str
+    ) -> tuple[CheckResult, Union[dict[str, Any], List[Any]]]:
+        security_values = conf.get("security", [{}]) or [{}]
+        security_definitions = conf.get("securityDefinitions", {}) or {}
         non_oauth2_keys = []
 
         for auth_key, auth_dict in security_definitions.items():
