@@ -20,6 +20,8 @@ class AbsRDSParameter(BaseResourceCheck):
         params = conf.get("parameters")
         if params and isinstance(params, list):
             for param in params:
+                if not isinstance(param, dict):
+                    return CheckResult.UNKNOWN
                 if param['name'][0] == self.parameter and (param['value'][0]).lower() == 'on':
                     return CheckResult.PASSED
         return CheckResult.FAILED
