@@ -11,10 +11,11 @@ class DocDBTLS(BaseResourceCheck):
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
     def scan_resource_conf(self, conf):
+        self.evaluated_keys = ['parameter']
         if 'parameter' in conf:
-            for elem in conf["parameter"]:
+            for idx, elem in enumerate(conf["parameter"]):
                 if isinstance(elem, dict) and elem["name"][0] == "tls" and elem["value"][0] == "disabled":
-                    self.evaluated_keys = [f'parameter/[{conf["parameter"].index(elem)}]/name', f'parameter/[{conf["parameter"].index(elem)}]/value']
+                    self.evaluated_keys = [f'parameter/[{idx}]/name', f'parameter/[{idx}]/value']
                     return CheckResult.FAILED
         return CheckResult.PASSED
 
