@@ -1,3 +1,5 @@
+from typing import List
+
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
 
@@ -13,13 +15,14 @@ class ELBAccessLogs(BaseResourceCheck):
     def scan_resource_conf(self, conf):
         if 'access_logs' not in conf:
             return CheckResult.FAILED
-        self.evaluated_keys = ['access_logs']
         if 'enabled' not in conf['access_logs'][0]:
             return CheckResult.PASSED
-        self.evaluated_keys = ['access_logs/[0]/enabled']
         if conf['access_logs'][0]['enabled'] == [True]:
             return CheckResult.PASSED
         return CheckResult.FAILED
 
+    def get_evaluated_keys(self) -> List[str]:
+        return ["access_logs/[0]/enabled"]
+
 
 check = ELBAccessLogs()
