@@ -30,7 +30,7 @@ class GoogleCloudPostgreSqlLogConnection(BaseResourceCheck):
                     else:  # treating use cases of the following database_flags parsing (list of dictionaries with arrays): 'database_flags': [{'name': ['<key>'], 'value': ['<value>']},{'name': ['<key>'], 'value': ['<value>']}]
                         flags = [{key: flag[key][0] for key in flag} for flag in flags]
                     for flag in flags:
-                        if (flag['name'] == 'log_connections') and (flag['value'] == 'on'):  # Must be explicitly set for check to pass
+                        if (isinstance(flag, dict) and flag['name'] == 'log_connections') and (flag['value'] == 'on'):  # Must be explicitly set for check to pass
                             self.evaluated_keys = ['database_version/[0]/POSTGRES',
                                                    f'{evaluated_keys_prefix}/[{flags.index(flag)}]/name',
                                                    f'{evaluated_keys_prefix}/[{flags.index(flag)}]/value']
