@@ -11,12 +11,23 @@ class ContainerSecurityContext(BaseResourceCheck):
         # Location: container .securityContext
         id = "CKV_K8S_30"
 
-        supported_resources = ['kubernetes_pod', 'kubernetes_pod_v1']
+        supported_resources = ['kubernetes_pod', 'kubernetes_pod_v1',
+                               'kubernetes_deployment', 'kubernetes_deployment_v1']
         categories = [CheckCategories.GENERAL_SECURITY]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
     def scan_resource_conf(self, conf) -> CheckResult:
         spec = conf.get('spec', [None])[0]
+        evaluated_keys_path = "spec"
+
+        template = spec.get("template")
+        if template and isinstance(template, list):
+            template = template[0]
+            template_spec = template.get("spec")
+            if template_spec and isinstance(template_spec, list):
+                spec = template_spec[0]
+                evaluated_keys_path = f'{evaluated_keys_path}/[0]/template/[0]/spec'
+
         if isinstance(spec, dict) and spec.get("container"):
             containers = spec.get("container")
 
@@ -24,7 +35,7 @@ class ContainerSecurityContext(BaseResourceCheck):
                 if type(container) != dict:
                     return CheckResult.UNKNOWN
                 if not container.get("security_context"):
-                    self.evaluated_keys = [f'spec/[0]/container/[{idx}]/security_context']
+                    self.evaluated_keys = [f'{evaluated_keys_path}/[0]/container/[{idx}]/security_context']
                     return CheckResult.FAILED
         return CheckResult.PASSED
 
