@@ -1,16 +1,20 @@
+from __future__ import annotations
+
+from typing import Any
+
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
 
 
 class LBTargetGroupDefinesHealthCheck(BaseResourceCheck):
-    def __init__(self):
+    def __init__(self) -> None:
         name = "Ensure HTTP HTTPS Target group defines Healthcheck"
         id = "CKV_NCP_1"
-        supported_resources = ['ncloud_lb_target_group']
-        categories = [CheckCategories.GENERAL_SECURITY]
+        supported_resources = ("ncloud_lb_target_group",)
+        categories = (CheckCategories.GENERAL_SECURITY,)
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
-    def scan_resource_conf(self, conf):
+    def scan_resource_conf(self, conf: dict[str, list[Any]]) -> CheckResult:
         if conf.get("protocol") in (["HTTP"], ["HTTPS"]):
             health_checks = conf.get("health_check")
             if health_checks and isinstance(health_checks, list):
@@ -21,4 +25,4 @@ class LBTargetGroupDefinesHealthCheck(BaseResourceCheck):
         return CheckResult.UNKNOWN
 
 
-check = LBTargetGroupDefinesHealthCheck()
\ No newline at end of file
+check = LBTargetGroupDefinesHealthCheck()
