@@ -2,8 +2,8 @@ from checkov.terraform.checks.resource.ncp.NACLInboundCheck import NACLInboundCh
 
 
 class NACLInbound20(NACLInboundCheck):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(check_id="CKV_NCP_8", port=20)
 
 
-check = NACLInbound20()
\ No newline at end of file
+check = NACLInbound20()
