@@ -11,6 +11,16 @@ def test_file_with_class_const():
     assert len(errors) == 0
 
 
+def test_file_with_class_special_attributes():
+    errors = run_validator_for_test_file('class_special_attributes_pass.py')
+    assert len(errors) == 0
+
+
 def test_dataclass_skip():
     errors = run_validator_for_test_file('dataclass_skip.py')
     assert len(errors) == 0
+
+
+def test_typing_class_skip():
+    errors = run_validator_for_test_file('typing_class_skip.py')
+    assert len(errors) == 0
